========
Usage
========


Main command::

    Usage: pyohio [OPTIONS] COMMAND [ARGS]...
    
      PyOhio-related tools.
    
    Options:
      -v, --verbose
      --help         Show this message and exit.
    
    Commands:
      schedule  Output the PyOhio schedule.

Schedule subcommand::
      
      Usage: pyohio schedule [OPTIONS]
    
      Output the PyOhio schedule.
    
    Options:
      -r, --remaining  Only sessions that have yet to start
      --after TEXT     Only sessions starting after (ex: "2016-07-30 13:30")
      --help           Show this message and exit.


